@@ -21,6 +21,7 @@ pub(crate) use helm::Helm;
 use helper::{group_nodes_by_region, group_nodes_by_zone, is_aks, is_eks, NamesAndContexts};
 use kubeconfig::KubeconfigExt;
 
+mod crd;
 mod helm;
 mod helper;
 mod kubeconfig;
@@ -346,6 +347,16 @@ impl Kubectl {
         .await
     }
 
+    pub(crate) async fn install_cluster_crd(&self, namespace: &str) -> anyhow::Result<()> {
+        let crd = self.install_crd().await?;
+        log::debug!("Created CRD: {:#?}", crd);
+        let name = self.cluster_name();
+        let cluster = self.create_statehub_cluster_crd(name, namespace).await?;
+        log::debug!("Created StatehubCluster: {:#?}", cluster);
+
+        Ok(())
+    }
+
     // TODO: implement provider fetch out of cluster
     pub(crate) async fn get_cluster_provider(&self) -> anyhow::Result<v0::Provider> {
         let nodes = self.all_nodes().await?;
