@@ -65,7 +65,7 @@ pub(crate) struct Cli {
     command: Command,
 }
 
-#[derive(Debug, StructOpt)]
+#[derive(Debug, PartialEq, StructOpt)]
 enum Command {
     #[structopt(about = "Authenticate against statehub service", display_order(0))]
     Login,
@@ -376,6 +376,28 @@ enum Command {
         cleanup_grace: String,
     },
 
+    #[structopt(
+        about = "Install Statehub Cluster CRD",
+        aliases = &["icc", "crd"],
+        display_order(1000),
+        setting(clap::AppSettings::Hidden)
+    )]
+    InstallClusterCrd {
+        #[structopt(help = "cluster name")]
+        cluster: v0::ClusterName,
+        #[structopt(
+            help = "Kubeconfig context to use for installing Statehub Cluster CRD",
+            long,
+            short
+        )]
+        context: Option<String>,
+        #[structopt(
+            help = "Namespace to install statehub components",
+            default_value = "statehub-system"
+        )]
+        namespace: String,
+    },
+
     #[structopt(
         about = "List K8s namespaces",
         alias = "list-ns",
@@ -436,7 +458,9 @@ impl Cli {
         let statehub = StateHub::new(config, self.json, self.verbose);
 
         statehub.check_for_update().await;
-        statehub.validate_auth().await?;
+        if self.command != Command::Login {
+            statehub.validate_auth().await?;
+        }
 
         match self.command {
             Command::Login => statehub.login().await,
@@ -597,6 +621,16 @@ impl Cli {
                     .setup_configmap(namespace, cluster, default_state, cleanup_grace)
                     .await
             }
+            Command::InstallClusterCrd {
+                cluster,
+                context,
+                namespace,
+            } => {
+                let names = vec![cluster];
+                let contexts = context.into_iter().collect();
+                let kubectls = k8s::Kubectl::with_names_and_contexts(names, contexts)?;
+                statehub.install_cluster_crd(kubectls, namespace).await
+            }
             Command::ListNamespaces => statehub.list_namespaces().await,
             Command::ListNodes => statehub.list_nodes().await,
             Command::ListPods => statehub.list_pods().await,
@@ -1005,6 +1039,18 @@ impl StateHub {
         Ok(())
     }
 
+    async fn install_cluster_crd(
+        &self,
+        kubectls: Vec<k8s::Kubectl>,
+        namespace: String,
+    ) -> anyhow::Result<()> {
+        for kubectl in kubectls {
+            kubectl.install_cluster_crd(&namespace).await?;
+        }
+
+        Ok(())
+    }
+
     async fn list_regions(&self, zone: bool) -> anyhow::Result<()> {
         k8s::Kubectl::new()?
             .get_regions(zone)
