@@ -6,7 +6,7 @@
 use serde::{Deserialize, Serialize};
 use structopt::StructOpt;
 
-#[derive(Debug, Default, Serialize, Deserialize, StructOpt)]
+#[derive(Debug, Default, Serialize, Deserialize, PartialEq, StructOpt)]
 #[serde(rename_all = "UPPERCASE")]
 pub(crate) struct AzureCredentials {
     // #[structopt(help = "Azure Tenant ID", long, requires_all = &["azure_client_id", "azure_client_secret"])]
