@@ -68,7 +68,7 @@ impl StateHub {
         let namespace = &register_cluster.namespace;
         let cluster = self
             .api
-            .register_cluster(&cluster_name, namespace, provider, locations)
+            .register_cluster(cluster_name, namespace, provider, locations)
             .await
             .map(Quiet)?;
 
@@ -272,34 +272,6 @@ or run following commands before running 'statehub register-cluster`
         Ok(())
     }
 
-    async fn _adjust_state_locations(
-        &self,
-        name: &v0::StateName,
-        locations: &[Location],
-    ) -> anyhow::Result<()> {
-        let state = self.api.get_state(name).await?;
-        let wait = false;
-
-        log::info!("Checking {}", state.show());
-        for location in locations {
-            if state.is_available_in(location) {
-                log::info!(
-                    "Skipping state {} which is already available in {}",
-                    state.name,
-                    location
-                );
-            } else {
-                self.inform(format_args!(
-                    "Extending state {} to {}",
-                    state.name, location
-                ))?;
-                self.add_location_helper(&state, location, wait).await?;
-            }
-        }
-
-        Ok(())
-    }
-
     pub(super) async fn setup_configmap_helper(
         &self,
         kubectl: &k8s::Kubectl,
